Changelog
=========

1.0.2 (2022-05-09)
------------------

- moved `to-annotation-overlay-od` into `wai.annotations.imgvis` module


1.0.1 (2022-05-04)
------------------

- added `-s/--scale-to` option to `to-annotation-overlay-od` command to scale all annotations
  to a predefined image size.
- overlay output of `to-annotation-overlay-od` is now enforcing PNG format


1.0.0 (2022-05-02)
------------------

- Initial release: label-dist-ic, label-dist-is, label-dist-od, to-annotation-overlay-od

